/***************************************************************
* L&L - Labyrinths & Legends
* Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
* 
* Created by BowKenKen
*   URL: https://sourceforge.jp/projects/lnl/
* 
* License is GPL
* 
* ܥץϥե꡼եȥǤ
* ʤϡ Free Software Foundation ɽ
*  GNU ̸ͭѵΡ֥С󣲡
* ϤʹߤγƥС椫餤줫򤷡
* ΥС˽äܥץ
* ۤޤѹ뤳ȤǤޤ
* 
* ܥץͭѤȤϻפޤۤˤäƤϡ
* ԾڤŪŬˤĤƤΰۤݾڤޤ,
* ʤݾڤԤʤޤ
* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
* 
* ʤϡܥץȰ GNU ̸ͭѵ
* μ̤äƤϤǤǤʤϡ
*   Free Software Foundation, Inc.,
*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
* ؼ񤤤Ƥ
* 
* $Id: draw.h,v 1.37 2004/12/25 06:33:08 bowkenken Exp $
***************************************************************/

#ifndef	DRAW_H
#define	DRAW_H

/***************************************************************
* 
***************************************************************/

#include	<stdio.h>

#include	"pet.h"
#include	"menu.h"
#include	"request.h"

/***************************************************************/

/* ϥե롦ݥ */
#define	OUT_FP	stdout

/***************************************************************
* ꡼󡦥
***************************************************************/

#define	SCREEN_WIDTH	80
#define	SCREEN_HEIGHT	24
#define	SCREEN_MIN_X	0
#define	SCREEN_MIN_Y	0
#define	SCREEN_MAX_X	(SCREEN_WIDTH - 1)
#define	SCREEN_MAX_Y	(SCREEN_HEIGHT - 1)

#define	WIN_MAP_WIDTH	20
#define	WIN_MAP_HEIGHT	20

/***************************************************************
* VFX
***************************************************************/

#define	VFX_ARW_MAX_N	32

/* ե졼ࡦ졼 */
#define	ANIM_FRAME_N	((long)(1.0 * 60.0))

#define	ANIM_LINE_LEN	32

/***************************************************************
* ʸVFX
***************************************************************/

#define	TYPHOON_DUST_MAX_N	24
#define	TYPHOON_SPEED	10
#define	ANIM_TYPHOON_SEC	(4.0)
#define	ANIM_TYPHOON_FRAME_N	(ANIM_FRAME_N * 5 / 100)

#define	ANIM_CONFLAGRATION_SEC	(4.0)
#define	ANIM_CONFLAGRATION_FRAME_N	(ANIM_FRAME_N * 5 / 100)
#define	ANIM_CONFLAGRATION_HEIGHT	(WIN_MAP_DRAW_HEIGHT / 2)

#define	ANIM_EARTHQUAKE_SEC	(4.0)
#define	ANIM_EARTHQUAKE_FRAME_N	(ANIM_FRAME_N * 1 / 10)

#define	ANIM_THUNDER_FRAME_N	(ANIM_FRAME_N * 5 / 100)
#define	ANIM_THUNDER_CLR_FRAME_N	(ANIM_FRAME_N * 20 / 10)
#define	ANIM_THUNDER_HEIGHT	(WIN_MAP_DRAW_HEIGHT / 2)

#define	ANIM_INUNDATION_FRAME_N	(ANIM_FRAME_N * 5 / 100)
#define	ANIM_INUNDATION_CLR_FRAME_N	(ANIM_FRAME_N * 20 / 10)

/***************************************************************
* ¾VFX
***************************************************************/

#define	ANIM_ARW_FRAME_N	\
		((ANIM_FRAME_N * 15 / 10) - ANIM_ARW_CLR_FRAME_N)
#define	ANIM_ARW_CLR_FRAME_N	(ANIM_FRAME_N * 5 / 10)

#define	ANIM_CRTCL_FRAME_N	\
		((ANIM_FRAME_N * 4 / 10) - ANIM_CRTCL_CLR_FRAME_N)
#define	ANIM_CRTCL_CLR_FRAME_N	(ANIM_FRAME_N * 2 / 10)
#define	ANIM_CRTCL_R	2
#define	ANIM_CRTCL_WAIT_CLOCK	(ANIM_FRAME_N * 4 / 10)
#define	STR_ANIM_CRTCL_1	"/"
#define	STR_ANIM_CRTCL_2	"\\"

#define	ANIM_NUM_FRAME_N	(ANIM_FRAME_N * 10 / 10)
#define	ANIM_LEV_UP_FRAME_N	(ANIM_FRAME_N * 30 / 10)

#define	ANIM_SPELL_LEN	8
#define	ANIM_SPELL_FRAME_N	\
		((ANIM_FRAME_N * 15 / 10) - ANIM_SPELL_CLR_FRAME_N)
#define	ANIM_SPELL_CLR_FRAME_N	(ANIM_FRAME_N * 5 / 10)

/***************************************************************
* ɥΥ
***************************************************************/

#define	WIN_MAP_DRAW_MIN_X	0
#define	WIN_MAP_DRAW_MIN_Y	0
#define	WIN_MAP_DRAW_WIDTH	(WIN_MAP_WIDTH * 2)
#define	WIN_MAP_DRAW_HEIGHT	WIN_MAP_HEIGHT
#define	WIN_MAP_DRAW_MAX_X	(WIN_MAP_DRAW_MIN_X + WIN_MAP_DRAW_WIDTH - 1)
#define	WIN_MAP_DRAW_MAX_Y	(WIN_MAP_DRAW_MIN_Y + WIN_MAP_DRAW_HEIGHT - 1)

#define	WIN_MENU_DRAW_MIN_X	SCREEN_MIN_X
#define	WIN_MENU_DRAW_MIN_Y	SCREEN_MIN_Y
#define	WIN_MENU_DRAW_WIDTH	(WIN_MENU_DRAW_MAX_X - WIN_MENU_DRAW_MIN_X)
#define	WIN_MENU_DRAW_HEIGHT	(WIN_MENU_DRAW_MAX_Y - WIN_MENU_DRAW_MIN_Y)
#define	WIN_MENU_DRAW_MAX_X	SCREEN_MAX_X
#define	WIN_MENU_DRAW_MAX_Y	(WIN_MSG_DRAW_MIN_Y - 1)

#define	WIN_MSG_DRAW_MIN_X	0
#define	WIN_MSG_DRAW_MIN_Y	(WIN_MAP_DRAW_MAX_Y + 2)
#define	WIN_MSG_DRAW_WIDTH	(SCREEN_WIDTH - 1)
#define	WIN_MSG_DRAW_HEIGHT	1
#define	WIN_MSG_DRAW_MAX_X	(WIN_MSG_DRAW_MIN_X + WIN_MSG_DRAW_WIDTH - 1)
#define	WIN_MSG_DRAW_MAX_Y	(WIN_MSG_DRAW_MIN_Y + WIN_MSG_DRAW_HEIGHT - 1)

#define	WIN_MORE_DRAW_MIN_X	(WIN_MSG_DRAW_MAX_X - WIN_MORE_DRAW_WIDTH + 1)
#define	WIN_MORE_DRAW_MIN_Y	WIN_MSG_DRAW_MIN_Y
#define	WIN_MORE_DRAW_WIDTH	(str_len_draw( MSG_MORE ))

#define	WIN_REQUEST_DRAW_WIDTH	40
#define	WIN_REQUEST_DRAW_MIN_Y	4

#define	WIN_STAT_DRAW_MIN_X	(WIN_MAP_DRAW_MAX_X + 1 + 1)
#define	WIN_STAT_DRAW_MIN_Y	0
#define	WIN_STAT_DRAW_WIDTH	\
		(WIN_STAT_DRAW_MAX_X - WIN_STAT_DRAW_MIN_X + 1)
#define	WIN_STAT_DRAW_HEIGHT	3
#define	WIN_STAT_DRAW_MAX_X	(SCREEN_WIDTH - 1)
#define	WIN_STAT_DRAW_MAX_Y	(WIN_STAT_DRAW_MIN_Y \
		+ ((MBR_MAX_N) * WIN_STAT_DRAW_HEIGHT - 1) - 1)

/***************************************************************
* åɽؿΥե饰
***************************************************************/

typedef unsigned long	flg_msg_t;

/* 顼 */
#define	FLG_MSG_ERR	(1 << 0)

/* ³Ԥ */
#define	FLG_MSG_MORE	(1 << 1)

/* 1³Ԥ̵ */
#define	FLG_MSG_NO_MORE_PREV	(1 << 2)

/* 1ļ³Ԥ̵ */
#define	FLG_MSG_NO_MORE_NEXT	(1 << 3)

/* ³Ԥ̵ */
#define	FLG_MSG_NO_MORE	(FLG_MSG_NO_MORE_PREV | FLG_MSG_NO_MORE_NEXT)

/* ǥХåΤɽ */
#define	FLG_MSG_DEBUG	(1 << 4)

/* åꥹȤɽԿ */
#define	LS_MSG_DRAW_N	20

/* åκԿ */
#define	LS_MSG_MAX_N	(LS_MSG_DRAW_N * 8)

/***************************************************************
* VFXΥե륿
***************************************************************/

typedef unsigned long	flg_vfx_mbr_t;
typedef unsigned long	flg_vfx_mnstr_t;

#define	FLG_VFX_MBR_CURE	(1 << 0)
#define	FLG_VFX_MBR_DAM	(1 << 1)
#define	FLG_VFX_MBR_CRTCL	(1 << 2)
#define	FLG_VFX_MBR_ARW	(1 << 3)
#define	FLG_VFX_MNSTR_CURE	(1 << 0)
#define	FLG_VFX_MNSTR_DAM	(1 << 1)
#define	FLG_VFX_MNSTR_CRTCL	(1 << 2)
#define	FLG_VFX_MNSTR_ARW	(1 << 3)

/***************************************************************
* VFXԤ
***************************************************************/

#define	VFX_WAIT_MIN_N	1
#define	VFX_WAIT_MAX_N	200

/***************************************************************
* ơ֥
***************************************************************/

/* ơ֥Υ */
#define	KEY_TAB_MAX_N	512

/***************************************************************
* ɽСǡμ
***************************************************************/

typedef enum {
	DATA_N_NULL,

	DATA_N_NAME,
	DATA_N_FACE,
	DATA_N_RACE_STR,
	DATA_N_RACE_NAME,
	DATA_N_SEX,

	DATA_N_HP_VAL,
	DATA_N_MP_VAL,

	DATA_N_VAL_TTL,
	DATA_N_HIT,
	DATA_N_WPN_CRTCL,
	DATA_N_DAM,
	DATA_N_DEF,
	DATA_N_ARMOR_CRTCL,
	DATA_N_AC,
	DATA_N_GOLD,
	DATA_N_TURN,

	DATA_N_STAT_TTL,
	DATA_N_STAT_DEAD,
	DATA_N_STAT_STONE,
	DATA_N_STAT_PARALYZE,
	DATA_N_STAT_POISON,
	DATA_N_STAT_CONFUSION,
	DATA_N_STAT_BLIND,
	DATA_N_STAT_SLEEP,
	DATA_N_STAT_SILENCE,
	DATA_N_STAT_CAUGHT,
	DATA_N_STAT_FEAR,
	DATA_N_STAT_HALLUCINATION,
	DATA_N_STAT_CHARM,
	DATA_N_STAT_FLY,
	DATA_N_STAT_HUNGRY,
	DATA_N_STAT_FAINT,
	DATA_N_STAT_DRUNK,
	DATA_N_STAT_VANISH,
	DATA_N_STAT_IRON_BODY,
	DATA_N_STAT_PASSWALL,

	DATA_N_LEV_LEFT,
	DATA_N_EXP_LEFT,
	DATA_N_NEED_EXP_LEFT,
	DATA_N_LEV_RIGHT,
	DATA_N_EXP_RIGHT,
	DATA_N_NEED_EXP_RIGHT,

	DATA_N_HP,
	DATA_N_MP,
	DATA_N_DEX,
	DATA_N_STR,
	DATA_N_AGI,
	DATA_N_INT,
	DATA_N_WIS,
	DATA_N_CHA,

	DATA_N_RESI_TTL,
	DATA_N_RESI_TTL_LAWFUL,
	DATA_N_RESI_TTL_NEUTRAL_1,
	DATA_N_RESI_TTL_CHAOTIC,
	DATA_N_RESI_TTL_GOOD,
	DATA_N_RESI_TTL_NEUTRAL_2,
	DATA_N_RESI_TTL_EVIL,
	DATA_N_RESI_KNOC,
	DATA_N_RESI_SLAS,
	DATA_N_RESI_STIN,
	DATA_N_RESI_HEAT,
	DATA_N_RESI_COLD,
	DATA_N_RESI_ACID,
	DATA_N_RESI_MIND,
	DATA_N_RESI_ELEC,
	DATA_N_RESI_POIS,

	DATA_N_FIG,
	DATA_N_MON,
	DATA_N_HUN,
	DATA_N_THI,
	DATA_N_MAG,
	DATA_N_SOR,
	DATA_N_ENC,
	DATA_N_SUM,
	DATA_N_PRI,
	DATA_N_SHA,
	DATA_N_BAR,
	DATA_N_NIN,

	DATA_N_CLASS,

	DATA_N_NEXT_PAGE,

	DATA_N_MAX_N,
} data_n_t;

/***************************************************************
* Խ륯饹ǡμ
***************************************************************/

typedef enum {
	EDIT_CLASS_NULL,

	EDIT_CLASS_HP,
	EDIT_CLASS_MP,
	EDIT_CLASS_DEX,
	EDIT_CLASS_STR,
	EDIT_CLASS_AGI,
	EDIT_CLASS_INT,
	EDIT_CLASS_WIS,
	EDIT_CLASS_CHA,

	EDIT_CLASS_TOTAL,

	EDIT_CLASS_FIG,
	EDIT_CLASS_MON,
	EDIT_CLASS_HUN,
	EDIT_CLASS_THI,
	EDIT_CLASS_MAG,
	EDIT_CLASS_SOR,
	EDIT_CLASS_ENC,
	EDIT_CLASS_SUM,
	EDIT_CLASS_PRI,
	EDIT_CLASS_SHA,
	EDIT_CLASS_BAR,
	EDIT_CLASS_NIN,

	EDIT_CLASS_NAME,

	EDIT_CLASS_PREV,
	EDIT_CLASS_NEXT,

	EDIT_CLASS_MAX_N,
} edit_class_t;

#endif	/* DRAW_H */

